@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..6\n"; }
+BEGIN { $| = 1; print "1..7\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Parse::FixedLength;
 $loaded = 1;
@@ -51,3 +51,8 @@ if ($parser->length == 40) {
 } else {
     print "not ok 6\n";
 }
+if ($parser->length('first_name') == 10) {
+    print "ok 7\n";
+} else {
+    print "not ok 7\n";
+}
